@@ -1,9 +1,7 @@
-import sys
-
 import click
 
 from mim.click import get_installed_package, param2lowercase
-from mim.utils import PKG2MODULE, call_command, remove_installation_records
+from mim.utils import call_command
 
 
 @click.command('uninstall')
@@ -38,11 +36,3 @@ def uninstall(package: str, confirm_yes=False) -> None:
         uninstall_cmd.append('-y')
 
     call_command(uninstall_cmd)
-    # if package is installed, importlib.import_module will import the
-    # package and add it to sys.modules. However, if we uninstall the
-    # package in the same process, is_installed will give a wrong result
-    # because importlib.import_module will search package from sys.modules
-    # first.
-    sys.modules.pop(PKG2MODULE.get(package, package), None)
-
-    remove_installation_records(package)
